@@ -18,14 +18,10 @@ class ID:
     @property
     def id(self):
         result = f'{self.service}_{self._app}_{self._view_set}'
-        result = result if self._lookup_field_value is None else f'{result}_{self._lookup_field_value}'
+        result = result if self.lookup_field_value is None else f'{result}_{self.lookup_field_value}'
         result = result if self._action is None else f'{result}_{self._action}'
         return result
 
-    @property
-    def service(self):
-        return self._service
-
     @property
     def path(self):
         result = f'/{self._app}' if self._view_set is None else f'/{self._app}/{self._view_set}'
@@ -34,8 +30,8 @@ class ID:
         return result
 
     @property
-    def url(self):
-        return f'https://{self.service}.expressmoney.com{self.path}'
+    def service(self):
+        return self._service
 
     @property
     def lookup_field_value(self):
