@@ -245,11 +245,13 @@ class ContractPoint(FilterMixin, CacheMixin, Point):
 
     def _get_page_data(self, url=None) -> list:
         get_data = self._get(url)
-        if self._cache or self._pagination_pages is None:
+        if self._cache is not None or self._pagination_pages is None:
             page_data = get_data
             if not isinstance(page_data, list):
                 raise PaginationError('Endpoint pagination enable.')
         else:
+            if isinstance(get_data, list):
+                raise PaginationError('Endpoint pagination disable.')
             self._next_pagination_page = get_data.get('next')
             page_data = get_data.get('results')
             if page_data is None:
