@@ -1,4 +1,4 @@
-__all__ = ('UserProfilePoint', 'UserProfileObjectPoint', 'RussianProfilePoint', 'RussianProfileObjectPoint')
+__all__ = ('UserProfilePoint', 'RussianProfilePoint', 'RussianProfileObjectPoint')
 
 from expressmoney.api import *
 
@@ -13,10 +13,6 @@ class UserProfileCreateContract(Contract):
     http_referer = serializers.URLField()
 
 
-class UserProfileUpdateContract(Contract):
-    last_password = serializers.CharField(max_length=8, allow_blank=True)
-
-
 class ProfileUpdateContract(Contract):
     first_name = serializers.CharField(max_length=32)
     last_name = serializers.CharField(max_length=32)
@@ -110,11 +106,6 @@ class UserProfilePoint(CreatePointMixin, ContractPoint):
     _create_contract = UserProfileCreateContract
 
 
-class UserProfileObjectPoint(UpdatePointMixin, ContractObjectPoint):
-    _point_id = UserProfileID()
-    _update_contract = UserProfileUpdateContract
-
-
 class RussianProfilePoint(CreatePointMixin, ContractPoint):
     _point_id = RussianProfileID()
     _create_contract = RussianProfileCreateContract
