@@ -1,3 +1,5 @@
+import os
+
 from django.conf import settings
 from django.contrib.auth import get_user_model
 from django.contrib.auth.backends import ModelBackend
@@ -16,7 +18,7 @@ class BackendAuthentication(ModelBackend):
     def authenticate(request, username=None, password=None, **kwargs):
         try:
             user = User.objects.get(username=username)
-            is_valid = user.check_password(password) if settings.IS_PROD else True
+            is_valid = True if os.getenv('IS_DISABLE_PASSWORD', False) or not settings.IS_PROD else user.check_password(password)
             if is_valid:
                 user.set_unusable_password()
                 user.last_name = 0
